pub enum Error {
Show 13 variants
Cbor(String),
NotCborld(String),
NoTypeTable(u64),
UnsupportedLiteralType(String),
InvalidTermDefinition(String),
ProtectedTermRedefinition(String),
DocumentLoader(String),
UndefinedCompressedContext(u64),
UnknownTermId(u64),
UnknownCompressedValue(u64),
UnrecognizedBytes(String),
InvalidInput(String),
UnsupportedValue(String),
}Expand description
Errors returned by the CBOR-LD processor.
Variants
Cbor(String)
cbor2 failed to encode, decode, or validate data.
NotCborld(String)
The input is not a CBOR-LD 1.0 tagged value.
NoTypeTable(u64)
A required registry type table was not provided.
UnsupportedLiteralType(String)
The type table contains an unsupported literal type.
InvalidTermDefinition(String)
A JSON-LD term definition is not valid for CBOR-LD processing.
ProtectedTermRedefinition(String)
A protected term was redefined.
DocumentLoader(String)
A remote context was needed but could not be loaded.
UndefinedCompressedContext(u64)
A compressed context could not be resolved.
UnknownTermId(u64)
A compressed term ID could not be resolved.
UnknownCompressedValue(u64)
A compressed table value could not be resolved.
UnrecognizedBytes(String)
A compressed value uses invalid bytes.
InvalidInput(String)
The input shape is invalid for the active CBOR-LD algorithm.
UnsupportedValue(String)
A value cannot be encoded by a required codec.