pub fn decode(cborld_bytes: &[u8], options: DecodeOptions<'_>) -> Result<Value>Expand description
Decodes CBOR-LD bytes into a JSON-LD document.
This helper works without a document loader and is sufficient for
uncompressed documents or compressed documents that only use inline
contexts. Use decode_with_loader when remote context URLs are present.